LobbyModFilter = LobbyModFilter or class()
LobbyModFilter.mod_path = ModPath
LobbyModFilter.lang_path = ModPath.."lang/"
LobbyModFilter.options_path = SavePath.."Lobby Mod Filter Options.json"
LobbyModFilter.blacklist_path = SavePath.."Lobby Mod Filter Blacklist.txt"
LobbyModFilter.options_def = {
	enabled = true,
	language = "en_US.json"
}
LobbyModFilter.blacklist_def = {
	"Pirate Perfection",
	"P3DHack",
	"Silent Assassin"
}

function LobbyModFilter:reload_options()
	self.options = {}
	local file = io.open(self.options_path, "r")
	if file then
		local decoded = json.decode(file:read("*a"))
		file:close()
		for key, value_def in pairs(self.options_def) do
			local value = decoded[key]
			if value == nil then
				value = value_def
			end
			self.options[key] = value
		end
	else
		for key, value in pairs(self.options_def) do
			self.options[key] = value
		end
	end
	self:save_options()
end

function LobbyModFilter:save_options()
	local file = io.open(self.options_path, "w")
	file:write(json.encode(self.options))
	file:close()
end

function LobbyModFilter:reload_blacklist()
	self.blacklist = {}
	local file = io.open(self.blacklist_path, "r")
	if file then
		for line in file:lines() do
			if #line > 0 then
				table.insert(self.blacklist, line)
			end
		end
	else
		file = io.open(self.blacklist_path, "w")
		for _, value in pairs(self.blacklist_def) do
			table.insert(self.blacklist, value)
			file:write(value)
			file:write("\n")
		end
	end
	file:close()
end

function LobbyModFilter:load_language(language)
	LocalizationManager:load_localization_file(self.lang_path..(language or self.options.language))
end

LobbyModFilter:reload_options()
LobbyModFilter:reload_blacklist()

function LobbyModFilter:show_options()
	local options = self.options
	QuickMenu:new(managers.localization:text("lobbymodfilter_options_title"),
	(options.enabled and managers.localization:text("lobbymodfilter_options_enabled") or managers.localization:text("lobbymodfilter_options_disabled")).."\n"
	..managers.localization:text("lobbymodfilter_options_blacklist")..table.concat(self.blacklist, ", "),
	{
		{
			text = "Language...",
			callback = function ()
				LobbyModFilter:show_language_options(function ()
					LobbyModFilter:show_options()
				end)
			end
		},
		{
			text = managers.localization:text("lobbymodfilter_options_toggle"),
			callback = function ()
				options.enabled = not options.enabled
				LobbyModFilter:save_options()
				managers.network.matchmake:search_lobby(managers.network.matchmake:search_friends_only())
				LobbyModFilter:show_options()
			end
		},
		{
			text = managers.localization:text("lobbymodfilter_options_reload_blacklist"),
			callback = function ()
				LobbyModFilter:reload_blacklist()
				managers.network.matchmake:search_lobby(managers.network.matchmake:search_friends_only())
				LobbyModFilter:show_options()
			end
		},
		{
			text = managers.localization:text("lobbymodfilter_options_close"),
			is_cancel_button = true
		}
	}):show()
end

function LobbyModFilter:show_language_options(back_callback)
	local menu_options = {}
	for _, lang in pairs(file.GetFiles(self.lang_path)) do
		table.insert(menu_options, {
			text = lang,
			callback = function ()
				LobbyModFilter.options.language = lang
				LobbyModFilter:save_options()
				LobbyModFilter:load_language()
				LobbyModFilter:show_language_options(back_callback)
			end
		})
	end
	table.insert(menu_options, {
		text = managers.localization:text("lobbymodfilter_options_close"),
		callback = back_callback
	})
	QuickMenu:new(managers.localization:text("lobbymodfilter_options_title").."-"..managers.localization:text("lobbymodfilter_options_language_title"),
	managers.localization:text("lobbymodfilter_language_name"),
	menu_options):show()
end

function LobbyModFilter:find_mods(mods)
	local found = {}
	if self.options.enabled and mods then
		for _, mod in pairs(self.blacklist) do
			if string.find(mods, mod) then
				table.insert(found, mod)
			end
		end
	end
	return found
end